@@ -5,8 +5,8 @@ from notecoin.strategy.utils import market_api
 
 
 class MarketCoins(RedisConnect):
-    def __init__(self, *args, **kwargs):
-        super(MarketCoins, self).__init__(*args, **kwargs)
+    def __init__(self, prefix='/market',cache_prefix='okex_market_tickets', *args, **kwargs):
+        super(MarketCoins, self).__init__(prefix=prefix,cache_prefix=cache_prefix, *args, **kwargs)
         add_api_routes(self)
 
     @api_route('/update', description="update market tickers")
